@@ -192,7 +192,7 @@ def daily_limit_unique_reached(invoker_name, recipient_name, level=1):
 def get_invoker_level(invoker_name):
 
     # check how much TOKEN the invoker has
-    wallet_token_info = Wallet(invoker_name).get_token(TOKEN_NAME)
+    wallet_token_info = api.Wallet(invoker_name).get_token(TOKEN_NAME)
 
     try:
         invoker_delegationsIn = float(wallet_token_info['delegationsIn'])
@@ -356,7 +356,7 @@ def main():
         # check how much TOKEN the bot has
         TOKEN_GIFT_AMOUNT = float(config['HiveEngine']['TOKEN_GIFT_AMOUNT'])
         
-        bot_balance = float(Wallet(ACCOUNT_NAME).get_token(TOKEN_NAME)['balance'])
+        bot_balance = float(api.Wallet(ACCOUNT_NAME).get_token(TOKEN_NAME)['balance'])
         if bot_balance < TOKEN_GIFT_AMOUNT:
 
             message_body = 'Bot wallet has run out of %s' % TOKEN_NAME
@@ -372,7 +372,7 @@ def main():
         if ENABLE_TRANSFERS:
             print('[*] Transfering %f %s from %s to %s' % (TOKEN_GIFT_AMOUNT, TOKEN_NAME, ACCOUNT_NAME, parent_author))
 
-            wallet = Wallet(ACCOUNT_NAME, blockchain_instance=HIVE)
+            wallet = api.Wallet(ACCOUNT_NAME, blockchain_instance=HIVE)
             wallet.stake(TOKEN_GIFT_AMOUNT, TOKEN_NAME, receiver=parent_author)
 
             today = str(date.today())
